@@ -1,17 +1,16 @@
-from django.conf import settings
-
 from jinja2.loaders import FileSystemLoader, PackageLoader
 
 from yammy.translator import yammy_to_html_string
 
 
 class YammyLoaderMixin(object):
+    DEBUG = False
 
     def get_html_source(self, get_source, environment, template):
         contents, filename, uptodate = get_source(environment, template)
         if filename.endswith(('.ymy', '.yammy')):
             contents = yammy_to_html_string(contents,
-                                            keep_line_numbers=settings.DEBUG)
+                                            keep_line_numbers=self.DEBUG)
         return contents, filename, uptodate
 
 
